Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: tests/corelib/date_time7_test.dart

Issue 11770004: Rename Date to DateTime. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments and keep Backwards-compatibility class Date. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/corelib/date_time6_test.dart ('k') | tests/corelib/date_time8_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/corelib/date_time7_test.dart
diff --git a/tests/corelib/date_time7_test.dart b/tests/corelib/date_time7_test.dart
index da6005e5be41a7b48f91c332e3e631e42ba17490..f9b8e943616c5db37f1fb998ce6cea84cf11e053 100644
--- a/tests/corelib/date_time7_test.dart
+++ b/tests/corelib/date_time7_test.dart
@@ -2,10 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test Date timeZoneName and timeZoneOffset getters.
testUtc() {
- var d = new Date.fromString("2012-03-04T03:25:38.123Z");
+ var d = new DateTime.fromString("2012-03-04T03:25:38.123Z");
Expect.equals("UTC", d.timeZoneName);
Expect.equals(0, d.timeZoneOffset.inSeconds);
}
@@ -33,11 +33,11 @@ testLocal() {
}
}
- var d = new Date.fromString("2012-01-02T13:45:23");
+ var d = new DateTime.fromString("2012-01-02T13:45:23");
String name = d.timeZoneName;
checkOffset(name, d.timeZoneOffset);
- d = new Date.fromString("2012-07-02T13:45:23");
+ d = new DateTime.fromString("2012-07-02T13:45:23");
name = d.timeZoneName;
checkOffset(name, d.timeZoneOffset);
}
@@ -2,10 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test Date timeZoneName and timeZoneOffset getters.
+// Test DateTime timeZoneName and timeZoneOffset getters.
testUtc() {
« no previous file with comments | « tests/corelib/date_time6_test.dart ('k') | tests/corelib/date_time8_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698